Key generator and validator
======================================
The command-line tool to generate random or deterministic key pair using NaCL cryptography. 



Requirements:
===================================
- Python 2.7.x runtime
- libsordium system package


Usage
====================================
    Usage: ava-key.py [OPTIONS] COMMAND [ARGS]...
    Options:
        -v, --verbose  Enables verbose mode.
        --help         Show this message and exit.

    Commands:
        generate
        validate
